@@ -185,7 +185,7 @@ class TableRenderer:
         """Return a header for the specified column.
         :param column the specified table column.
         """
-        return titlecase(elide_text(self._headers[column], self._cell_size(column)))
+        return titlecase(elide_text(self._headers[column], self._cell_size(column)), skip_length=1)
 
     def _cell_text(self, row: tuple, column: int) -> str:
         """Return a text for the specified cell (row, column).
